@@ -15,20 +15,21 @@ summary.bekk <- function(object, ...) {
   cat(bekkObject$AIC)
   cat("\nBIC: ")
   cat(bekkObject$BIC)
-  cat("\nEstimated paramater matrices: \n")
+  cat("\nEstimated parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0)
   cat("\nA \n")
   print(bekkObject$A)
   cat("\nG \n")
   print(bekkObject$G)
-  cat("\nt-values of paramater matrices: \n")
+  cat("\nt-values of parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0_t)
   cat("\nA \n")
   print(bekkObject$A_t)
   cat("\nG \n")
   print(bekkObject$G_t)
+  cat("\n")
 }
 
 #' @export
@@ -47,7 +48,7 @@ summary.bekka <- function(object, ...) {
   cat(bekkObject$AIC)
   cat("\nBIC: ")
   cat(bekkObject$BIC)
-  cat("\nEstimated paramater matrices: \n")
+  cat("\nEstimated parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0)
   cat("\nA \n")
@@ -56,7 +57,7 @@ summary.bekka <- function(object, ...) {
   print(bekkObject$B)
   cat("\nG \n")
   print(bekkObject$G)
-  cat("\nt-values of paramater matrices: \n")
+  cat("\nt-values of parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0_t)
   cat("\nA \n")
@@ -65,6 +66,7 @@ summary.bekka <- function(object, ...) {
   print(bekkObject$B_t)
   cat("\nG \n")
   print(bekkObject$G_t)
+  cat("\n")
 }
 
 #' @export
@@ -84,20 +86,21 @@ summary.dbekk <- function(object, ...) {
   cat(bekkObject$AIC)
   cat("\nBIC: ")
   cat(bekkObject$BIC)
-  cat("\nEstimated paramater matrices: \n")
+  cat("\nEstimated parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0)
   cat("\nA \n")
   print(bekkObject$A)
   cat("\nG \n")
   print(bekkObject$G)
-  cat("\nt-values of paramater matrices: \n")
+  cat("\nt-values of parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0_t)
   cat("\nA \n")
   print(bekkObject$A_t)
   cat("\nG \n")
   print(bekkObject$G_t)
+  cat("\n")
 }
 
 #' @export
@@ -116,7 +119,7 @@ summary.dbekka <- function(object, ...) {
   cat(bekkObject$AIC)
   cat("\nBIC: ")
   cat(bekkObject$BIC)
-  cat("\nEstimated paramater matrices: \n")
+  cat("\nEstimated parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0)
   cat("\nA \n")
@@ -125,7 +128,7 @@ summary.dbekka <- function(object, ...) {
   print(bekkObject$B)
   cat("\nG \n")
   print(bekkObject$G)
-  cat("\nt-values of paramater matrices: \n")
+  cat("\nt-values of parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0_t)
   cat("\nA \n")
@@ -134,6 +137,7 @@ summary.dbekka <- function(object, ...) {
   print(bekkObject$B_t)
   cat("\nG \n")
   print(bekkObject$G_t)
+  cat("\n")
 }
 
 
@@ -154,20 +158,21 @@ summary.sbekk <- function(object, ...) {
   cat(bekkObject$AIC)
   cat("\nBIC: ")
   cat(bekkObject$BIC)
-  cat("\nEstimated paramater matrices: \n")
+  cat("\nEstimated parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0)
   cat("\na \n")
   print(bekkObject$a)
   cat("\ng \n")
   print(bekkObject$g)
-  cat("\nt-values of paramater matrices: \n")
+  cat("\nt-values of parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0_t)
   cat("\na \n")
   print(bekkObject$a_t)
   cat("\ng \n")
   print(bekkObject$g_t)
+  cat("\n")
 }
 
 #' @export
@@ -186,7 +191,7 @@ summary.sbekka <- function(object, ...) {
   cat(bekkObject$AIC)
   cat("\nBIC: ")
   cat(bekkObject$BIC)
-  cat("\nEstimated paramater matrices: \n")
+  cat("\nEstimated parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0)
   cat("\na \n")
@@ -195,7 +200,7 @@ summary.sbekka <- function(object, ...) {
   print(bekkObject$b)
   cat("\ng \n")
   print(bekkObject$g)
-  cat("\nt-values of paramater matrices: \n")
+  cat("\nt-values of parameter matrices: \n")
   cat("\nC \n")
   print(bekkObject$C0_t)
   cat("\na \n")
@@ -204,4 +209,5 @@ summary.sbekka <- function(object, ...) {
   print(bekkObject$b_t)
   cat("\ng \n")
   print(bekkObject$g_t)
+  cat("\n")
 }
